@@ -1,5 +1,5 @@
 /* Copyright 2012 Jesper K. Pedersen <blackie@kde.org>
-  
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
@@ -7,12 +7,12 @@
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -27,6 +27,7 @@
 #include <KMessageBox>
 #include <MainWindow/Window.h>
 #include <DB/ImageDB.h>
+#include <DB/CategoryCollection.h>
 #include "MainWindow/TokenEditor.h"
 #include "Utilities/Set.h"
 #include "MainWindow/DirtyIndicator.h"
@@ -140,7 +141,8 @@ void ExtractOneVideoFrame::markShortVideo(const DB::FileName &fileName)
     }
 
     DB::ImageInfoPtr info = DB::ImageDB::instance()->info(fileName);
-    info->addCategoryInfo(QString::fromUtf8("Tokens"), s_tokenForShortVideos);
+    DB::CategoryPtr tokensCategory = DB::ImageDB::instance()->categoryCollection()->categoryForSpecial(DB::Category::TokensCategory);
+    info->addCategoryInfo(tokensCategory->name(), s_tokenForShortVideos);
     MainWindow::DirtyIndicator::markDirty();
 }
 
