@@ -60,7 +60,7 @@ public:
     void processDrop(QTreeWidgetItem* draggedItem, QTreeWidgetItem* targetItem);
 
 public slots:
-    void categoryRenamed();
+    void categoryChangesPending();
     void slotPageChange();
     void discardChanges();
 
@@ -105,7 +105,7 @@ private: // Variables
     QLabel* m_tagsInGroupLabel;
     bool m_dataChanged;
     QList<QMap<CategoryEdit, QString>> m_categoryChanges;
-    QLabel* m_pendingRenameLabel;
+    QLabel* m_pendingChangesLabel;
 };
 
 }
